@@ -80,7 +80,7 @@
 	  (save-excursion
 	    (set-buffer nntp-server-buffer)
 	    (erase-buffer)
-	    (nnheader-insert-file-contents nov)
+	    (mm-insert-file-contents nov)
 	    (nnheader-nov-delete-outside-range
 	     (car articles) (car (last articles)))
 	    'nov))))))
@@ -119,7 +119,7 @@
 	  (nnkiboze-request-scan group))
 	(if (not (file-exists-p nov-file))
 	    (nnheader-report 'nnkiboze "Can't select group %s" group)
-	  (nnheader-insert-file-contents nov-file)
+	  (mm-insert-file-contents nov-file)
 	  (if (zerop (buffer-size))
 	      (nnheader-insert "211 0 0 0 %s\n" group)
 	    (goto-char (point-min))
@@ -138,7 +138,7 @@
 	     nnkiboze-remove-read-articles)
     (with-temp-file (nnkiboze-nov-file-name)
       (let ((cur (current-buffer)))
-	(nnheader-insert-file-contents (nnkiboze-nov-file-name))
+	(mm-insert-file-contents (nnkiboze-nov-file-name))
 	(goto-char (point-min))
 	(while (not (eobp))
 	  (if (not (gnus-article-read-p (read cur)))
@@ -209,7 +209,7 @@ Finds out what articles are to be part of the nnkiboze groups."
 
 (defun nnkiboze-generate-group (group)
   (let* ((info (nth 2 (gnus-gethash group gnus-newsrc-hashtb)))
-	 (newsrc-file (concat nnkiboze-directory 
+	 (newsrc-file (concat nnkiboze-directory
                               (nnheader-translate-file-chars
                                (concat group ".newsrc"))))
 	 (nov-file (concat nnkiboze-directory
@@ -287,7 +287,7 @@ Finds out what articles are to be part of the nnkiboze groups."
 					   (car ginfo)))
 				  0))
 			   (progn
-			     (ignore-errors 
+			     (ignore-errors
 			       (gnus-group-select-group nil))
 			     (eq major-mode 'gnus-summary-mode)))
 		  ;; We are now in the group where we want to be.
